==> odata-client-microsoft-dynamics-0.1.88-sources.jar: microsoft/dynamics/crm/entity/Msdyn_solutionhistorydatasource.java <==
package microsoft.dynamics.crm.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;
import java.util.UUID;

@JsonPropertyOrder({
    "@odata.type", 
    "msdyn_name", 
    "msdyn_solutionhistorydatasourceid"})
@JsonInclude(Include.NON_NULL)
public class Msdyn_solutionhistorydatasource extends Crmbaseentity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource";
    }

    @JsonProperty("msdyn_name")
    protected String msdyn_name;

    @JsonProperty("msdyn_solutionhistorydatasourceid")
    protected UUID msdyn_solutionhistorydatasourceid;

    protected Msdyn_solutionhistorydatasource() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMsdyn_solutionhistorydatasource() {
        return new Builder();
    }

    public static final class Builder {
        private String msdyn_name;
        private UUID msdyn_solutionhistorydatasourceid;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder msdyn_name(String msdyn_name) {
            this.msdyn_name = msdyn_name;
            this.changedFields = changedFields.add("msdyn_name");
            return this;
        }

        public Builder msdyn_solutionhistorydatasourceid(UUID msdyn_solutionhistorydatasourceid) {
            this.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
            this.changedFields = changedFields.add("msdyn_solutionhistorydatasourceid");
            return this;
        }

        public Msdyn_solutionhistorydatasource build() {
            Msdyn_solutionhistorydatasource _x = new Msdyn_solutionhistorydatasource();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource";
            _x.msdyn_name = msdyn_name;
            _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && msdyn_solutionhistorydatasourceid != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(msdyn_solutionhistorydatasourceid, UUID.class));
        }
    }

    @Property(name="msdyn_name")
    @JsonIgnore
    public Optional<String> getMsdyn_name() {
        return Optional.ofNullable(msdyn_name);
    }

    public Msdyn_solutionhistorydatasource withMsdyn_name(String msdyn_name) {
        Checks.checkIsAscii(msdyn_name);
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = changedFields.add("msdyn_name");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource");
        _x.msdyn_name = msdyn_name;
        return _x;
    }

    @Property(name="msdyn_solutionhistorydatasourceid")
    @JsonIgnore
    public Optional<UUID> getMsdyn_solutionhistorydatasourceid() {
        return Optional.ofNullable(msdyn_solutionhistorydatasourceid);
    }

    public Msdyn_solutionhistorydatasource withMsdyn_solutionhistorydatasourceid(UUID msdyn_solutionhistorydatasourceid) {
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = changedFields.add("msdyn_solutionhistorydatasourceid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource");
        _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
        return _x;
    }

    public Msdyn_solutionhistorydatasource withUnmappedField(String name, String value) {
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Msdyn_solutionhistorydatasource patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Msdyn_solutionhistorydatasource put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Msdyn_solutionhistorydatasource _copy() {
        Msdyn_solutionhistorydatasource _x = new Msdyn_solutionhistorydatasource();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.msdyn_name = msdyn_name;
        _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Msdyn_solutionhistorydatasource[");
        b.append("msdyn_name=");
        b.append(this.msdyn_name);
        b.append(", ");
        b.append("msdyn_solutionhistorydatasourceid=");
        b.append(this.msdyn_solutionhistorydatasourceid);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-microsoft-dynamics-0.2.0-sources.jar: microsoft/dynamics/crm/entity/Msdyn_solutionhistorydatasource.java <==
package microsoft.dynamics.crm.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;
import java.util.UUID;

@JsonPropertyOrder({
    "@odata.type", 
    "msdyn_name", 
    "msdyn_solutionhistorydatasourceid"})
@JsonInclude(Include.NON_NULL)
public class Msdyn_solutionhistorydatasource extends Crmbaseentity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource";
    }

    @JsonProperty("msdyn_name")
    protected String msdyn_name;

    @JsonProperty("msdyn_solutionhistorydatasourceid")
    protected UUID msdyn_solutionhistorydatasourceid;

    protected Msdyn_solutionhistorydatasource() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMsdyn_solutionhistorydatasource() {
        return new Builder();
    }

    public static final class Builder {
        private String msdyn_name;
        private UUID msdyn_solutionhistorydatasourceid;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder msdyn_name(String msdyn_name) {
            this.msdyn_name = msdyn_name;
            this.changedFields = changedFields.add("msdyn_name");
            return this;
        }

        public Builder msdyn_solutionhistorydatasourceid(UUID msdyn_solutionhistorydatasourceid) {
            this.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
            this.changedFields = changedFields.add("msdyn_solutionhistorydatasourceid");
            return this;
        }

        public Msdyn_solutionhistorydatasource build() {
            Msdyn_solutionhistorydatasource _x = new Msdyn_solutionhistorydatasource();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource";
            _x.msdyn_name = msdyn_name;
            _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && msdyn_solutionhistorydatasourceid != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(msdyn_solutionhistorydatasourceid, UUID.class));
        }
    }

    @Property(name="msdyn_name")
    @JsonIgnore
    public Optional<String> getMsdyn_name() {
        return Optional.ofNullable(msdyn_name);
    }

    public Msdyn_solutionhistorydatasource withMsdyn_name(String msdyn_name) {
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = changedFields.add("msdyn_name");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource");
        _x.msdyn_name = msdyn_name;
        return _x;
    }

    @Property(name="msdyn_solutionhistorydatasourceid")
    @JsonIgnore
    public Optional<UUID> getMsdyn_solutionhistorydatasourceid() {
        return Optional.ofNullable(msdyn_solutionhistorydatasourceid);
    }

    public Msdyn_solutionhistorydatasource withMsdyn_solutionhistorydatasourceid(UUID msdyn_solutionhistorydatasourceid) {
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = changedFields.add("msdyn_solutionhistorydatasourceid");
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.msdyn_solutionhistorydatasource");
        _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
        return _x;
    }

    public Msdyn_solutionhistorydatasource withUnmappedField(String name, Object value) {
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Msdyn_solutionhistorydatasource patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Msdyn_solutionhistorydatasource put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Msdyn_solutionhistorydatasource _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Msdyn_solutionhistorydatasource _copy() {
        Msdyn_solutionhistorydatasource _x = new Msdyn_solutionhistorydatasource();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.msdyn_name = msdyn_name;
        _x.msdyn_solutionhistorydatasourceid = msdyn_solutionhistorydatasourceid;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Msdyn_solutionhistorydatasource[");
        b.append("msdyn_name=");
        b.append(this.msdyn_name);
        b.append(", ");
        b.append("msdyn_solutionhistorydatasourceid=");
        b.append(this.msdyn_solutionhistorydatasourceid);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
